@@ -5,7 +5,7 @@ import sys
 import gi
 gi.require_version("Gtk", "2.0")
 
-from gi.repository import Gtk, Gdk
+from gi.repository import Gtk, Gdk, GdkPixbuf
 import keybinding
 
 
@@ -60,9 +60,6 @@ class mintMenuConfig( object ):
         self.builder.get_object("label11").set_text(_("Border width:"))
         self.builder.get_object("label25").set_text(_("pixels"))
 
-        self.builder.get_object("label8").set_text(_("Opacity:"))
-        self.builder.get_object("label9").set_text("%")
-
         self.builder.get_object("buttonTextLabel").set_text(_("Button text:"))
         self.builder.get_object("label1").set_text(_("Options"))
         self.builder.get_object("label23").set_text(_("Applications"))
@@ -134,7 +131,6 @@ class mintMenuConfig( object ):
         self.systemIconSize = self.builder.get_object( "systemIconSize" )
         self.favCols = self.builder.get_object( "numFavCols" )
         self.borderWidth = self.builder.get_object( "borderWidth" )
-        self.opacity = self.builder.get_object( "opacity" )
         self.useCustomColors = self.builder.get_object( "useCustomColors" )
         self.backgroundColor = self.builder.get_object( "backgroundColor" )
         self.borderColor = self.builder.get_object( "borderColor" )
@@ -185,7 +181,7 @@ class mintMenuConfig( object ):
         self.systemHeightButton = self.builder.get_object( "systemHeightSpinButton" )
         if (self.allowSystemScrollbarToggle.get_active() == False): self.systemHeightButton.set_sensitive(False)
         self.allowSystemScrollbarToggle.connect("toggled", self.toggleSystemHeightEnabled )
-        if os.path.exists("/usr/lib/linuxmint/mintInstall/icon.svg"):
+        if os.path.exists("/usr/bin/mintinstall"):
             self.builder.get_object( "softwaremanagercheckbutton" ).show()
         else:
             self.builder.get_object( "softwaremanagercheckbutton" ).hide()
@@ -217,7 +213,6 @@ class mintMenuConfig( object ):
         self.bindGSettingsValueToWidget( self.settingsSystem, "int", "icon-size", self.systemIconSize, "value-changed", self.systemIconSize.set_value, self.systemIconSize.get_value )
 
         self.bindGSettingsValueToWidget( self.settings, "int", "border-width", self.borderWidth, "value-changed", self.borderWidth.set_value, self.borderWidth.get_value_as_int )
-        self.bindGSettingsValueToWidget( self.settings, "int", "opacity", self.opacity, "value-changed", self.opacity.set_value, self.opacity.get_value_as_int )
         self.bindGSettingsValueToWidget( self.settings, "bool", "use-custom-color", self.useCustomColors, "toggled", self.useCustomColors.set_active, self.useCustomColors.get_active )
         self.bindGSettingsValueToWidget( self.settings, "color", "custom-color", self.backgroundColor, "color-set", self.backgroundColor.set_color, self.getBackgroundColor )
         self.bindGSettingsValueToWidget( self.settings, "color", "custom-heading-color", self.headingColor, "color-set", self.headingColor.set_color, self.getHeadingColor )
@@ -348,7 +343,8 @@ class mintMenuConfig( object ):
 
     def setButtonIcon( self, value ):
         self.buttonIconChooser.set_filename(value)
-        self.buttonIconImage.set_from_file(value)
+        pixbuf = GdkPixbuf.Pixbuf.new_from_file_at_size(value, -1, 22)
+        self.buttonIconImage.set_from_pixbuf(pixbuf)
 
     def getShowButtonIcon( self ):
         return not self.showButtonIcon.get_active()
@@ -386,18 +382,27 @@ class mintMenuConfig( object ):
         self.headingColorLabel.set_sensitive(  widget.get_active() )
 
     def getBackgroundColor( self ):
-        color = Gdk.Color(0,0,0)
-        self.backgroundColor.get_color(color)
+        try:
+            color = self.backgroundColor.get_color()
+        except:
+            color = Gdk.Color(0, 0, 0)
+            self.backgroundColor.get_color(color)
         return self.gdkColorToString( color )
 
     def getBorderColor( self ):
-        color = Gdk.Color(0,0,0)
-        self.borderColor.get_color(color)
+        try:
+            color = self.borderColor.get_color()
+        except:
+            color = Gdk.Color(0, 0, 0)
+            self.borderColor.get_color(color)
         return self.gdkColorToString( color )
 
     def getHeadingColor( self ):
-        color = Gdk.Color(0,0,0)
-        self.headingColor.get_color(color)
+        try:
+            color = self.headingColor.get_color()
+        except:
+            color = Gdk.Color(0, 0, 0)
+            self.headingColor.get_color(color)
         return self.gdkColorToString( color )
 
     def gdkColorToString( self, gdkColor ):
