@@ -132,8 +132,8 @@ class pluginclass( object ):
     def do_standard_items( self ):
 
         if ( self.showSoftwareManager == True ):
-            if os.path.exists("/usr/lib/linuxmint/mintInstall/icon.svg"):
-                Button1 = easyButton( "/usr/lib/linuxmint/mintInstall/icon.svg", self.iconsize, [_("Software Manager")], -1, -1 )
+            if os.path.exists("/usr/bin/mintinstall"):
+                Button1 = easyButton( "mintinstall", self.iconsize, [_("Software Manager")], -1, -1 )
                 Button1.connect( "clicked", self.ButtonClicked, "gksu mintinstall" )
                 Button1.show()
                 self.systemBtnHolder.pack_start( Button1, False, False, 0)
@@ -141,7 +141,7 @@ class pluginclass( object ):
 
         if ( self.showPackageManager == True ):
             Button2 = easyButton( "applications-system", self.iconsize, [_("Package Manager")], -1, -1 )
-            Button2.connect( "clicked", self.ButtonClicked, "gksu /usr/sbin/synaptic" )
+            Button2.connect( "clicked", self.ButtonClicked, "synaptic-pkexec" )
             Button2.show()
             self.systemBtnHolder.pack_start( Button2, False, False, 0 )
             self.mintMenuWin.setTooltip( Button2, _("Install, remove and upgrade software packages") )
